"""This module is for the translation mapping data of the
following document:

Document file: array_reverse.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Array class reverse interface": "# Array クラスの reverse インターフェイス",
    ##################################################
    "This page explains the `Array` class `reverse` method interface.": "このページでは`Array`クラスの`reverse`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `reverse` method interface reverses an array's values order in place.": "`reverse`メソッドは配列の値を直接更新する形で値の順番を逆順にします。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `reverse` method requires no arguments and returns no value.": "`reverse`メソッドは引数の指定を必要としません。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\narr: ap.Array[int] = ap.Array([1, 3, 5])\narr.reverse()\nassert arr == [5, 3, 1]\n```": "```py\n# runnable\nimport apysc as ap\n\narr: ap.Array[int] = ap.Array([1, 3, 5])\narr.reverse()\nassert arr == [5, 3, 1]\n```",  # noqa
    ##################################################
    "## See also": "## 関連資料",
    ##################################################
    "- [Array class sort interface](array_sort.md)": "- [Array クラスの sort インターフェイス](jp_array_sort.md)",  # noqa
    ##################################################
    "## reverse API": "## reverse API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Reverse this array in place.<hr>": "この配列の値を直接逆順にします。<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> arr: ap.Array = ap.Array([1, 2, 3])\n>>> arr.reverse()\n>>> arr\nArray([3, 2, 1])\n```": "```py\n>>> import apysc as ap\n>>> arr: ap.Array = ap.Array([1, 2, 3])\n>>> arr.reverse()\n>>> arr\nArray([3, 2, 1])\n```",  # noqa
}



"""Class implementation for the scale_y_from_center mix-in.
"""

from typing import Dict

from typing_extensions import final

from apysc._animation.animation_scale_y_from_center_mixin import (
    AnimationScaleYFromCenterMixIn,
)
from apysc._display.set_lower_scale_limit_mixin import SetLowerScaleLimitMixIn
from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.attr_linking_mixin import AttrLinkingMixIn
from apysc._type.number import Number
from apysc._type.revert_mixin import RevertMixIn
from apysc._type.variable_name_suffix_attr_mixin import VariableNameSuffixAttrMixIn
from apysc._validation import arg_validation_decos


class ScaleYFromCenterMixIn(
    VariableNameSuffixAttrMixIn,
    AnimationScaleYFromCenterMixIn,
    SetLowerScaleLimitMixIn,
    RevertMixIn,
    AttrLinkingMixIn,
):

    _scale_y_from_center: Number

    @final
    @add_debug_info_setting(module_name=__name__)
    def _initialize_scale_y_from_center_if_not_initialized(self) -> None:
        """
        Initialize the `_scale_y_from_center` attribute if this
        instance does not initialize it yet.
        """
        import apysc as ap

        if hasattr(self, "_scale_y_from_center"):
            return
        suffix: str = self._get_attr_variable_name_suffix(
            attr_identifier="scale_y_from_center"
        )
        self._scale_y_from_center = ap.Number(
            1.0,
            variable_name_suffix=suffix,
            skip_init_substitution_expression_appending=True,
        )

        self._append_scale_y_from_center_attr_linking_setting()

    @final
    @add_debug_info_setting(module_name=__name__)
    def _append_scale_y_from_center_attr_linking_setting(self) -> None:
        """
        Append a scale-y attribute linking settings.
        """
        self._append_applying_new_attr_val_exp(
            new_attr=self._scale_y_from_center, attr_name="scale_y_from_center"
        )
        self._append_attr_to_linking_stack(
            attr=self._scale_y_from_center, attr_name="scale_y_from_center"
        )

    @property
    @add_debug_info_setting(module_name=__name__)
    def scale_y_from_center(self) -> Number:
        """
        Get a scale-y value from the center of this instance.

        Returns
        -------
        scale_y_from_center : ap.Number
            Scale-y value from the center of this instance.

        Notes
        -----
        The scale's minimum value is almost zero, and it does not become negative.

        References
        ----------
        - GraphicsBase scale_x_from_center and scale_y_from_center interfaces
            - https://simon-ritchie.github.io/apysc/en/graphics_base_scale_from_center.html  # noqa

        Examples
        --------
        >>> import apysc as ap
        >>> stage: ap.Stage = ap.Stage()
        >>> sprite: ap.Sprite = ap.Sprite()
        >>> sprite.graphics.begin_fill(color="#0af")
        >>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(
        ...     x=50, y=50, width=50, height=50
        ... )
        >>> rectangle.scale_y_from_center = ap.Number(1.5)
        >>> rectangle.scale_y_from_center
        Number(1.5)
        """
        from apysc._type import value_util

        self._initialize_scale_y_from_center_if_not_initialized()
        return value_util.get_copy(value=self._scale_y_from_center)

    @scale_y_from_center.setter
    @arg_validation_decos.is_apysc_num(arg_position_index=1)
    @add_debug_info_setting(module_name=__name__)
    def scale_y_from_center(self, value: Number) -> None:
        """
        Update a scale-y value from the center of this instance.

        Parameters
        ----------
        value : ap.Number
            Scale-y value from the center of this instance.

        Notes
        -----
        The scale's minimum value is almost zero, and it does not become negative.

        References
        ----------
        - GraphicsBase scale_x_from_center and scale_y_from_center interfaces
            - https://simon-ritchie.github.io/apysc/en/graphics_base_scale_from_center.html  # noqa
        """
        import apysc as ap

        self._initialize_scale_y_from_center_if_not_initialized()
        before_value: ap.Number = self._scale_y_from_center
        self._set_lower_scale_limit(value=value)
        self._scale_y_from_center = value
        self._append_scale_y_from_center_update_expression(before_value=before_value)

        self._append_scale_y_from_center_attr_linking_setting()

    @final
    @add_debug_info_setting(module_name=__name__)
    def _append_scale_y_from_center_update_expression(
        self, *, before_value: Number
    ) -> None:
        """
        Append the scale-y from the center of this instance
        updating expression.

        Parameters
        ----------
        before_value : ap.Number
            Before updating value.
        """
        import apysc as ap
        from apysc._type import value_util

        before_value_str: str = value_util.get_value_str_for_expression(
            value=before_value
        )
        after_value_str: str = value_util.get_value_str_for_expression(
            value=self._scale_y_from_center
        )
        expression: str = (
            f"{self.variable_name}.scale(1, 1 / {before_value_str});"
            f"\n{self.variable_name}.scale(1, {after_value_str});"
            f"\n{before_value_str} = {after_value_str};"
        )
        ap.append_js_expression(expression=expression)

    _scale_y_from_center_snapshots: Dict[str, float]

    def _make_snapshot(self, *, snapshot_name: str) -> None:
        """
        Make a value snapshot.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        self._initialize_scale_y_from_center_if_not_initialized()
        self._set_single_snapshot_val_to_dict(
            dict_name="_scale_y_from_center_snapshots",
            value=self._scale_y_from_center._value,
            snapshot_name=snapshot_name,
        )

    def _revert(self, *, snapshot_name: str) -> None:
        """
        Revert a value if a snapshot exists.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        if not self._snapshot_exists(snapshot_name=snapshot_name):
            return
        self._scale_y_from_center._value = self._scale_y_from_center_snapshots[
            snapshot_name
        ]



"""Class implementation for mouse move mix-in.
"""

from typing import Callable
from typing import Dict
from typing import Optional
from typing import TypeVar

from typing_extensions import final

from apysc._event.handler import HandlerData
from apysc._event.mouse_event import MouseEvent
from apysc._event.mouse_event_binding_expression_mixin import (
    MouseEventBindingExpressionMixin,
)
from apysc._event.mouse_event_unbinding_mixin import MouseEventUnbindingMixIn
from apysc._html.debug_mode import add_debug_info_setting
from apysc._validation import arg_validation_decos

_O = TypeVar("_O")
_Handler = Callable[[MouseEvent, _O], None]


class MouseMoveMixIn(MouseEventUnbindingMixIn, MouseEventBindingExpressionMixin):

    _mouse_move_handlers: Dict[str, HandlerData[MouseEvent]]

    @final
    @arg_validation_decos.handler_args_num(arg_position_index=1)
    @arg_validation_decos.handler_options_type(arg_position_index=2)
    @add_debug_info_setting(module_name=__name__)
    def mousemove(self, handler: _Handler[_O], *, options: Optional[_O] = None) -> str:
        """
        Add mouse move event listener setting.

        Parameters
        ----------
        handler : _Handler
            Callable that would be called when mousemove on this instance.
        options : dict or None, default None
            Optional arguments dictionary to be passed to a handler.

        Returns
        -------
        name : str
            Handler's name.

        References
        ----------
        - Mousemove interface
            - https://simon-ritchie.github.io/apysc/en/mousemove.html
        - About the handler options' type
            - https://simon-ritchie.github.io/apysc/en/about_handler_options_type.html  # noqa

        Examples
        --------
        >>> import apysc as ap
        >>> def on_mousemove(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:
        ...     stage_x: ap.Int = e.stage_x
        ...     ap.trace("stage_x:", stage_x)
        >>> stage: ap.Stage = ap.Stage()
        >>> sprite: ap.Sprite = ap.Sprite()
        >>> sprite.graphics.begin_fill(color="#0af")
        >>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(
        ...     x=50, y=50, width=50, height=50
        ... )
        >>> _ = rectangle.mousemove(on_mousemove)
        """
        import apysc as ap
        from apysc._event.handler import append_handler_expression
        from apysc._event.handler import get_handler_name
        from apysc._type.variable_name_mixin import VariableNameMixIn
        from apysc._validation.variable_name_validation import (
            validate_variable_name_interface_type,
        )

        self_instance: VariableNameMixIn = validate_variable_name_interface_type(
            instance=self
        )
        self._initialize_mouse_move_handlers_if_not_initialized()
        name: str = get_handler_name(handler=handler, instance=self)
        self._set_handler_data(
            handler=handler, handlers_dict=self._mouse_move_handlers, options=options
        )
        self._append_mouse_event_binding_expression(
            name=name, mouse_event_type=ap.MouseEventType.MOUSEMOVE
        )
        e: ap.MouseEvent = ap.MouseEvent(this=self_instance)
        append_handler_expression(
            handler_data=self._mouse_move_handlers[name], handler_name=name, e=e
        )
        return name

    @final
    def _initialize_mouse_move_handlers_if_not_initialized(self) -> None:
        """
        Initialize _mouse_move_handlers attribute if this
        interface does not initialize it yet.
        """
        if hasattr(self, "_mouse_move_handlers"):
            return
        self._mouse_move_handlers = {}

    @final
    @arg_validation_decos.handler_args_num(arg_position_index=1)
    @add_debug_info_setting(module_name=__name__)
    def unbind_mousemove(self, handler: _Handler[_O]) -> None:
        """
        Unbind a specified handler's mouse move event.

        Parameters
        ----------
        handler : _Handler
            Unbinding target Callable.

        References
        ----------
        - Mousemove interface
            - https://simon-ritchie.github.io/apysc/en/mousemove.html

        Examples
        --------
        >>> import apysc as ap
        >>> def on_mousemove(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:
        ...     stage_x: ap.Int = e.stage_x
        ...     ap.trace("stage_x:", stage_x)
        >>> def on_click(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:
        ...     rectangle: ap.Rectangle = e.this
        ...     rectangle.unbind_mousemove(on_mousemove)
        >>> stage: ap.Stage = ap.Stage()
        >>> sprite: ap.Sprite = ap.Sprite()
        >>> sprite.graphics.begin_fill(color="#0af")
        >>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(
        ...     x=50, y=50, width=50, height=50
        ... )
        >>> _ = rectangle.mousemove(on_mousemove)
        >>> _ = rectangle.click(on_click)
        """
        import apysc as ap

        self._initialize_mouse_move_handlers_if_not_initialized()
        self._unbind_mouse_event(
            handler=handler,
            mouse_event_type=ap.MouseEventType.MOUSEMOVE,
            handlers_dict=self._mouse_move_handlers,
        )

    @final
    @add_debug_info_setting(module_name=__name__)
    def unbind_mousemove_all(self) -> None:
        """
        Unbind all mouse move events.

        References
        ----------
        - Mousemove interface
            - https://simon-ritchie.github.io/apysc/en/mousemove.html

        Examples
        --------
        >>> import apysc as ap
        >>> def on_mousemove(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:
        ...     stage_x: ap.Int = e.stage_x
        ...     ap.trace("stage_x:", stage_x)
        >>> def on_click(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:
        ...     rectangle: ap.Rectangle = e.this
        ...     rectangle.unbind_mousemove_all()
        >>> stage: ap.Stage = ap.Stage()
        >>> sprite: ap.Sprite = ap.Sprite()
        >>> sprite.graphics.begin_fill(color="#0af")
        >>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(
        ...     x=50, y=50, width=50, height=50
        ... )
        >>> _ = rectangle.mousemove(on_mousemove)
        >>> _ = rectangle.click(on_click)
        """
        import apysc as ap

        self._initialize_mouse_move_handlers_if_not_initialized()
        self._unbind_all_mouse_events(
            mouse_event_type=ap.MouseEventType.MOUSEMOVE,
            handlers_dict=self._mouse_move_handlers,
        )



"""This module is for the translation mapping data of the
following document:

Document file: stage.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Stage class": "# Stage クラス",
    ##################################################
    "This page explains the `Stage` class.": "このページでは`Stage`クラスについて説明します。",
    ##################################################
    "## What is the Stage?": "## Stage クラスの概要",
    ##################################################
    "The `Stage` is the apysc overall drawing area (like a viewport) and contains all elements.": "`Stage`クラスはapyscにおける描画エリア全体を扱うインスタンスを作成し、各要素を格納します。",  # noqa
    ##################################################
    "You must create the `Stage` at the first of the apysc project (this runs cleaning up internal data and files).": "apyscのプロジェクトの最初で`Stage`のインスタンスを作成する必要があります（この時点で内部でデータやファイルの古いものの削除などが実行されます）。",  # noqa
    ##################################################
    "## Create stage": "## ステージの作成",
    ##################################################
    "Creating a stage is simple, like this:": "ステージの作成は以下のコード例のようにシンプルです:",
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage()\n```": "```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage()\n```",  # noqa
    ##################################################
    "## Stage background color setting": "## ステージの背景色設定",
    ##################################################
    "`Stage` class has a `background_color` option, which changes the stage's background color.": "`Stage`クラスは`background_color`のオプションの引数を持っており、この引数でステージの背景色を変更することができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(background_color="#333", stage_elem_id="stage")\n\nap.save_overall_html(dest_dir_path="stage_background_color/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(background_color="#333", stage_elem_id="stage")\n\nap.save_overall_html(dest_dir_path="stage_background_color/")\n```',  # noqa
    ##################################################
    "This will create HTML with black background stage, as follows:": "このコードは以下のように黒背景のステージのHTMLを生成します:",  # noqa
    ##################################################
    "## Stage size setting": "## ステージのサイズ設定",
    ##################################################
    "`Stage` class has options to set stage width and stage height (arguments of `stage_width` and `stage_height`). These settings change stage sizes.": "`Stage`クラスはステージの幅を設定する`stage_width`引数とステージの高さを設定する`stage_height`引数を持っています。これらの設定はステージのサイズを変更します。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=500, stage_height=50, background_color="#333", stage_elem_id="stage"\n)\n\nap.save_overall_html(dest_dir_path="stage_size/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=500, stage_height=50, background_color="#333", stage_elem_id="stage"\n)\n\nap.save_overall_html(dest_dir_path="stage_size/")\n```',  # noqa
    ##################################################
    "The Previous script will create a horizontal stage, as follows:": "上記のコードは以下のように横長のステージを作成します:",  # noqa
    ##################################################
    "## Stage element id setting": "## ステージの要素のID設定",
    ##################################################
    "Stage element id (HTML id) can be set by `stage_elem_id` argument. If you don't specify this, the apysc sets any unique id (based on created timestamp, like `stage_12345...`).": "ステージの要素のID（HTMLのID）は`stage_elem_id`引数で設定することができます。もしもこの設定を指定しない場合、apyscはステージ生成時のタイムスタンプや乱数などをベースとした一意なIDを生成します（例 : `stage_12345...`）。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(background_color="#333", stage_elem_id="line_chart_1")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(background_color="#333", stage_elem_id="line_chart_1")\n```',  # noqa
    ##################################################
    "This option is useful when using the apysc project multiple times (for an easily identifiable ID) or version control.": "このオプションはapyscの各プロジェクトで複数回出力などを行う際のIDの識別やバージョン管理などの面で便利です。",  # noqa
    ##################################################
    "## Stage class constructor API": "## Stage クラスのコンストラクタのAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Create Stage (overall viewport) instance.<hr>": "ステージ（描画領域全体）のインスタンスを生成します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `stage_width`: int, default 300": "- `stage_width`: int, default 300",
    ##################################################
    "  - Stage width.": "  - ステージの幅。",
    ##################################################
    "- `stage_height`: int, default 185": "- `stage_height`: int, default 185",
    ##################################################
    "  - Stage height": "  - ステージの高さ。",
    ##################################################
    "- `background_color`: str, default '#ffffff'": "- `background_color`: str, default '#ffffff'",  # noqa
    ##################################################
    "  - Hexadecimal background color string.": "  - 16進数の背景色の文字列。",
    ##################################################
    "- `add_to`: str, default 'body'": "- `add_to`: str, default 'body'",
    ##################################################
    "  - Specification of element to add stage. Unique tag (e.g., 'body') or ID selector (e.g., '#any-unique-elem') is acceptable.": "  - ステージの要素を追加先となる要素の指定。一意のタグ（例 : 'body'）やIDのセレクタ（例 : '#any-unique-elem'）を受け付けることができます。",  # noqa
    ##################################################
    "- `stage_elem_id`: str or None, optional": "- `stage_elem_id`: str or None, optional",  # noqa
    ##################################################
    "  - ID attribute set to stage HTML element (e.g., 'line-graph'). If None is set, a random integer will be applied.": "  - ステージのHTML要素に設定されるIDの属性（例 : 'line-graph'）。もしNoneが設定されている場合、乱数などを使った数値を使った値が設定されます。",  # noqa
    ##################################################
    "- `variable_name_suffix`: str, default ''": "- `variable_name_suffix`: str, default ''",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript's debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     stage_width=500,\n...     stage_height=300,\n...     background_color="#333",\n...     stage_elem_id="sales_chart",\n... )\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     stage_width=500,\n...     stage_height=300,\n...     background_color="#333",\n...     stage_elem_id="sales_chart",\n... )\n```',  # noqa
    ##################################################
    "## stage_elem_id property API": "## stage_elem_id 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get stage's html element id.<hr>": "ステージのHTML要素のIDを取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `stage_elem_id`: str": "- `stage_elem_id`: str",
    ##################################################
    "  - Stage's html element id (not including class or id symbol). e.g., 'line-graph'": "  - ステージのHTML要素のID（ID用の#の記号などは含まれません。例 : 'line-graph'）。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     stage_width=500,\n...     stage_height=300,\n...     background_color="#333",\n...     stage_elem_id="sales_chart",\n... )\n>>> stage.stage_elem_id\n\'sales_chart\'\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     stage_width=500,\n...     stage_height=300,\n...     background_color="#333",\n...     stage_elem_id="sales_chart",\n... )\n>>> stage.stage_elem_id\n\'sales_chart\'\n```',  # noqa
    ##################################################
    "## add_child API": "## add_child API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Add display object child to this instance.<hr>": "表示オブジェクトの子をこのインスタンスへと追加します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `child`: DisplayObject": "- `child`: DisplayObject",
    ##################################################
    "  - Child instance to add.": "  - 追加する子のインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite_1: ap.Sprite = ap.Sprite()\n>>> sprite_1.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite_1.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> sprite_2: ap.Sprite = ap.Sprite()\n>>> sprite_2.add_child(rectangle)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite_1: ap.Sprite = ap.Sprite()\n>>> sprite_1.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite_1.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> sprite_2: ap.Sprite = ap.Sprite()\n>>> sprite_2.add_child(rectangle)\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [add_child and remove_child interfaces](https://simon-ritchie.github.io/apysc/en/add_child_and_remove_child.html)": "- [add_child （子の追加）と remove_child （子の削除）のインターフェイス](https://simon-ritchie.github.io/apysc/jp/jp_add_child_and_remove_child.html)",  # noqa
    ##################################################
    "## remove_child API": "## remove_child API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Remove display object child from this instance.<hr>": "このインスタンスから指定された表示オブジェクトの子を取り除きます。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `child`: DisplayObject": "- `child`: DisplayObject",
    ##################################################
    "  - Child instance to remove.": "  - 取り除く対象の子のインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> sprite.graphics.remove_child(rectangle)\n>>> print(rectangle.parent)\nNone\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> sprite.graphics.remove_child(rectangle)\n>>> print(rectangle.parent)\nNone\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [add_child and remove_child interfaces](https://simon-ritchie.github.io/apysc/en/add_child_and_remove_child.html)": "- [add_child （子の追加）と remove_child （子の削除）のインターフェイス](https://simon-ritchie.github.io/apysc/jp/jp_add_child_and_remove_child.html)",  # noqa
    ##################################################
    "## contains API": "## contains API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a boolean whether this instance contains a specified child.<hr>": "指定された子のインスタンスを持っているかどうかの真偽値を取得します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `child`: DisplayObject": "- `child`: DisplayObject",
    ##################################################
    "  - Child instance to check.": "  - チェック対象の子のインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `result`: Boolean": "- `result`: Boolean",
    ##################################################
    "  - If this instance contains a specified child, this method returns True.": "  - このインスタンスが指定された子を持つ場合Trueが設定されます。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> sprite.graphics.contains(rectangle)\nBoolean(True)\n\n>>> rectangle.remove_from_parent()\n>>> sprite.graphics.contains(rectangle)\nBoolean(False)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> sprite.graphics.contains(rectangle)\nBoolean(True)\n\n>>> rectangle.remove_from_parent()\n>>> sprite.graphics.contains(rectangle)\nBoolean(False)\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [contains interface](https://simon-ritchie.github.io/apysc/en/contains.html)": "- [contains インターフェイス](https://simon-ritchie.github.io/apysc/jp/jp_contains.html)",  # noqa
    ##################################################
    "## num_children property API": "## num_children property API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a current children's number.<hr>": "現在の子の数を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `num_children`: int": "- `num_children`: int",
    ##################################################
    "  - Current children number.": "  - 現在の子の数。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle_1: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle_2: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=150, y=50, width=50, height=50\n... )\n>>> sprite.graphics.num_children\nInt(2)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle_1: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle_2: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=150, y=50, width=50, height=50\n... )\n>>> sprite.graphics.num_children\nInt(2)\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [num_children interface](https://simon-ritchie.github.io/apysc/en/num_children.html)": "- [num_children （子の件数属性）のインターフェイス](https://simon-ritchie.github.io/apysc/jp/jp_num_children.html)",  # noqa
    ##################################################
    "## get_child_at API": "## get_child_at API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a child at a specified index.<hr>": "指定されたインデックスの子を取得します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `index`: int or Int": "- `index`: int or Int",
    ##################################################
    "  - Child's index (start from 0).": "  - 対象の子のインデックス（0からスタートします）。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `child`: DisplayObject": "- `child`: DisplayObject",
    ##################################################
    "  - Target index child instance.": "  - 対象の子のインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle_1: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle_2: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=150, y=50, width=50, height=50\n... )\n>>> child_at_index_1: ap.DisplayObject = sprite.graphics.get_child_at(1)\n>>> child_at_index_1 == rectangle_2\nTrue\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af", alpha=0.5)\n>>> rectangle_1: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle_2: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=150, y=50, width=50, height=50\n... )\n>>> child_at_index_1: ap.DisplayObject = sprite.graphics.get_child_at(1)\n>>> child_at_index_1 == rectangle_2\nTrue\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [get_child_at interface](https://simon-ritchie.github.io/apysc/en/get_child_at.html)": "- [get_child_at （特定位置の子の取得処理）のインターフェイス](https://simon-ritchie.github.io/apysc/jp/jp_get_child_at.html)",  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: unset_debug_mode.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# unset_debug_mode interface": "# unset_debug_mode インターフェイス",
    ##################################################
    "This page explains the `unset_debug_mode` function interface.": "このページでは`unset_debug_mode`関数のインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `unset_debug_mode` function interface unsets the debug mode setting. It stops the debug information appending.": "`unset_debug_mode`関数のインターフェイスはデバッグモードの設定を解除します。この関数はデバッグ情報の追加を停止します。",  # noqa
    ##################################################
    "The debug mode exports lots of information. Sometimes it becomes cumbersome. In that case, stopping the debug mode is helpful when it is no longer needed.": "デバッグモードの設定は大量の情報を出力します。時折これは煩雑な（情報が多すぎる）状態になることがあります。そのような場合にデバッグモードが不要になったタイミングで設定を解除すると役に立つことがあります。",  # noqa
    ##################################################
    "## Notes": "## 特記事項",
    ##################################################
    "If the exporting interface (e.g., `ap.save_overall_html`) `minify` option is enabled, it removes debug mode information. So it is required to set the `minify=False` when you use the `unset_debug_mode` interface.": "もしも出力のインターフェイス（例 : `ap.save_overall_html`など）の`minify`のオプションが有効になっていると、デバッグモードの情報なども削除されてしまいます。そのため`unset_debug_mode`インターフェイスでデバッグモードを解除した場合には`minify=False`の引数設定が必要になります。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `unset_debug_mode` interface requires no arguments.": "`unset_debug_mode`インターフェイスは引数の指定を必要としません。",  # noqa
    ##################################################
    "The following example appends the debug information only at the `int_1` instantiation and incremental addition of 10.": "以下のコード例では`int_1`の変数のインスタンス化と10の加算処理の箇所のみデバッグ情報の追加を有効化しています。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=150, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nap.set_debug_mode()\nint_1: ap.Int = ap.Int(10)\nint_1 += 10\nap.unset_debug_mode()\nint_2: ap.Int = ap.Int(20)\nint_2 += 20\n\nap.save_overall_html(minify=False, dest_dir_path="unset_debug_mode_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=150, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nap.set_debug_mode()\nint_1: ap.Int = ap.Int(10)\nint_1 += 10\nap.unset_debug_mode()\nint_2: ap.Int = ap.Int(20)\nint_2 += 20\n\nap.save_overall_html(minify=False, dest_dir_path="unset_debug_mode_basic_usage/")\n```',  # noqa
    ##################################################
    "The exported HTML includes the debug information at the first integer position. It doesn't include the sprite and second integer positions, as follows:": "出力されたHTMLでは最初の整数部分のデバッグ情報を以下のように含んでいます。その後のスプライトや2つ目の整数関係の位置のものは含まれないようになっています:",  # noqa
    ##################################################
    "```js\n...\n  var sp_1 = stage.nested();\n  var g_1 = stage.nested();\n  arr_2.push(g_1);\n  var i_12 = -1;\n  i_12 = arr_2.indexOf(g_1);\n  var b_3 = false;\n  var i_13 = -1;\n...\n  //////////////////////////////////////////////////////////////////////\n  // [__init__ 12] started.\n  // module name: apysc._type.int\n  // class: Int\n  // arguments and variables:\n  //    value = 10\n  //    self = 0()\n    //////////////////////////////////////////////////////////////////////\n    // [__init__ 14] started.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    // arguments and variables:\n    //    type_name = 'i'\n    //    value = 10\n    //    self = 0(i_16)\n    // [__init__ 14] ended.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    //////////////////////////////////////////////////////////////////////\n    //////////////////////////////////////////////////////////////////////\n    // [to_int_from_float 14] started.\n    // module name: apysc._converter.cast\n    // arguments and variables:\n    //    int_or_float = 10\n    // [to_int_from_float 14] ended.\n    // module name: apysc._converter.cast\n    //////////////////////////////////////////////////////////////////////\n    //////////////////////////////////////////////////////////////////////\n    // [append_constructor_expression 14] started.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    // arguments and variables:\n    //    self = 10(i_16)\n      var i_16 = 10;\n    // [append_constructor_expression 14] ended.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    //////////////////////////////////////////////////////////////////////\n...\n  var i_18 = 20;\n  var i_19 = cpy(i_18);\n  var i_19 = i_18 + 20;\n  i_18 = i_19;\n...\n```": "```js\n...\n  var sp_1 = stage.nested();\n  var g_1 = stage.nested();\n  arr_2.push(g_1);\n  var i_12 = -1;\n  i_12 = arr_2.indexOf(g_1);\n  var b_3 = false;\n  var i_13 = -1;\n...\n  //////////////////////////////////////////////////////////////////////\n  // [__init__ 12] started.\n  // module name: apysc._type.int\n  // class: Int\n  // arguments and variables:\n  //    value = 10\n  //    self = 0()\n    //////////////////////////////////////////////////////////////////////\n    // [__init__ 14] started.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    // arguments and variables:\n    //    type_name = 'i'\n    //    value = 10\n    //    self = 0(i_16)\n    // [__init__ 14] ended.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    //////////////////////////////////////////////////////////////////////\n    //////////////////////////////////////////////////////////////////////\n    // [to_int_from_float 14] started.\n    // module name: apysc._converter.cast\n    // arguments and variables:\n    //    int_or_float = 10\n    // [to_int_from_float 14] ended.\n    // module name: apysc._converter.cast\n    //////////////////////////////////////////////////////////////////////\n    //////////////////////////////////////////////////////////////////////\n    // [append_constructor_expression 14] started.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    // arguments and variables:\n    //    self = 10(i_16)\n      var i_16 = 10;\n    // [append_constructor_expression 14] ended.\n    // module name: apysc._type.number_value_mixin\n    // class: NumberValueMixIn\n    //////////////////////////////////////////////////////////////////////\n...\n  var i_18 = 20;\n  var i_19 = cpy(i_18);\n  var i_19 = i_18 + 20;\n  i_18 = i_19;\n...\n```",  # noqa
    ##################################################
    "## See also": "## 関連資料",
    ##################################################
    "- [set_debug_mode interface](set_debug_mode.md)": "- [set_debug_mode インターフェイス](jp_set_debug_mode.md)",  # noqa
    ##################################################
    "## unset_debug_mode API": "## unset_debug_mode API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Unset the debug mode for the HTML and JavaScript debugging.<hr>": "HTMLとJavaScriptのデバッグ用のデバッグモードの設定を解除します。<hr>",  # noqa
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> ap.set_debug_mode()\n>>> int_val: ap.Int = ap.Int(10)\n>>> ap.unset_debug_mode()\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> ap.set_debug_mode()\n>>> int_val: ap.Int = ap.Int(10)\n>>> ap.unset_debug_mode()\n```",  # noqa
}



"""Base class for each animation mix-in.
"""

from apysc._animation.animation_finish_mixin import AnimationFinishMixIn
from apysc._animation.animation_pause_mixin import AnimationPauseMixIn
from apysc._animation.animation_play_mixin import AnimationPlayMixIn
from apysc._animation.animation_reset_mixin import AnimationResetMixIn
from apysc._animation.animation_reverse_mixin import AnimationReverseMixIn
from apysc._animation.animation_time_mixin import AnimationTimeMixIn


class AnimationMixIns(
    AnimationPauseMixIn,
    AnimationPlayMixIn,
    AnimationResetMixIn,
    AnimationFinishMixIn,
    AnimationReverseMixIn,
    AnimationTimeMixIn,
):
    """Base class for each animation mix-in."""



"""This module is for the translation mapping data of the
following document:

Document file: graphics_draw_dash_dotted_line.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Graphics draw_dash_dotted_line interface": "# Graphics クラスの draw_dash_dotted_line インターフェイス",  # noqa
    ##################################################
    "This page explains the `Graphics` class `draw_dash_dotted_line` method interface.": "このページでは`Graphics`クラスの`draw_dash_dotted_line`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "`draw_dash_dotted_line` interface draws the simple straight dash dotted-line (also called 1-dot chain line or long dashed short dashed line) graphics.": "`draw_dash_dotted_line`インターフェイスはシンプルな一点鎖線の直線を描画します。",  # noqa
    ##################################################
    "This interface will ignore `dot_setting`, `dash_setting`, `round_dot_setting`, and `dash_dot_setting`.": "このインターフェイスは`dot_setting`や`dash_setting`、`round_dot_setting`、`dash_dot_setting`の引数や属性設定を無視します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "`draw_dash_dotted_line` interface has basic coordinates arguments of `x_start`, `y_start`, `x_end` and `y_end`. That also has `dot_size` (the short dash size), `dash_size` (the long dash size) and `space_size` (the space size between the each dashes) arguments to determine line style.": "`draw_dash_dotted_line`インターフェイスは基本的な座標指定の引数として`x_start`、`y_start`、`x_end`、`y_end`の引数を持っています。加えて、短い点線部分のサイズとしての`dot_size`引数、長い破線部分のサイズとしての`dash_size`引数、そしてそれぞれの点線と破線の間のスペースとして`space_size`の引数が必要になります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=250, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 2-pixel dot size and 6-pixel dash size and draw the line.\nsprite.graphics.line_style(color="#0af", thickness=5)\nsprite.graphics.draw_dash_dotted_line(\n    x_start=50, y_start=50, x_end=200, y_end=50, dot_size=2, dash_size=6, space_size=5\n)\n\n# Set 5-pixel dot size and 10-pixel dash size and draw the line.\nsprite.graphics.draw_dash_dotted_line(\n    x_start=50, y_start=80, x_end=200, y_end=80, dot_size=5, dash_size=10, space_size=5\n)\n\nap.save_overall_html(dest_dir_path="graphics_draw_dash_dotted_line_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=250, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 2-pixel dot size and 6-pixel dash size and draw the line.\nsprite.graphics.line_style(color="#0af", thickness=5)\nsprite.graphics.draw_dash_dotted_line(\n    x_start=50, y_start=50, x_end=200, y_end=50, dot_size=2, dash_size=6, space_size=5\n)\n\n# Set 5-pixel dot size and 10-pixel dash size and draw the line.\nsprite.graphics.draw_dash_dotted_line(\n    x_start=50, y_start=80, x_end=200, y_end=80, dot_size=5, dash_size=10, space_size=5\n)\n\nap.save_overall_html(dest_dir_path="graphics_draw_dash_dotted_line_basic_usage/")\n```',  # noqa
    ##################################################
    "## draw_dash_dotted_line API": "## draw_dash_dotted_line API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Draw a dash-dotted (1-dot chain) line vector graphics.<hr>": "一点鎖線のベクターグラフィックスの線を描画します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `x_start`: Int or int": "- `x_start`: Int or int",
    ##################################################
    "  - Line start x-coordinate.": "  - 線の開始位置のX座標。",
    ##################################################
    "- `y_start`: Int or int": "- `y_start`: Int or int",
    ##################################################
    "  - Line start y-coordinate.": "  - 線の開始位置のY座標。",
    ##################################################
    "- `x_end`: Int or int": "- `x_end`: Int or int",
    ##################################################
    "  - Line end x-coordinate.": "  - 線の終了位置のX座標。",
    ##################################################
    "- `y_end`: Int or int": "- `y_end`: Int or int",
    ##################################################
    "  - Line end y-coordinate.": "  - 線の終了位置のY座標。",
    ##################################################
    "- `dot_size`: Int or int": "- `dot_size`: Int or int",
    ##################################################
    "  - Dot size.": "  - ドットのサイズ。",
    ##################################################
    "- `dash_size`: Int or int": "- `dash_size`: Int or int",
    ##################################################
    "  - Dash size.": "  - 破線部分のサイズ。",
    ##################################################
    "- `space_size`: Int or int": "- `space_size`: Int or int",
    ##################################################
    "  - Blank space size between dots and dashes.": "  - ドット（点線）や破線間の空白スペースのサイズ。",
    ##################################################
    "- `variable_name_suffix`: str, default ''": "- `variable_name_suffix`: str, default ''",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript's debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line`: Line": "- `line`: Line",
    ##################################################
    "  - Created line graphics instance.": "  - 生成された線のグラフィックスのインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color=\"#fff\", thickness=5)\n>>> line: ap.Line = sprite.graphics.draw_dash_dotted_line(\n...     x_start=50,\n...     y_start=50,\n...     x_end=150,\n...     y_end=50,\n...     dot_size=2,\n...     dash_size=5,\n...     space_size=3,\n... )\n>>> line.line_color\nString('#ffffff')\n\n>>> line.line_dash_dot_setting.dot_size\nInt(2)\n\n>>> line.line_dash_dot_setting.dash_size\nInt(5)\n\n>>> line.line_dash_dot_setting.space_size\nInt(3)\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color=\"#fff\", thickness=5)\n>>> line: ap.Line = sprite.graphics.draw_dash_dotted_line(\n...     x_start=50,\n...     y_start=50,\n...     x_end=150,\n...     y_end=50,\n...     dot_size=2,\n...     dash_size=5,\n...     space_size=3,\n... )\n>>> line.line_color\nString('#ffffff')\n\n>>> line.line_dash_dot_setting.dot_size\nInt(2)\n\n>>> line.line_dash_dot_setting.dash_size\nInt(5)\n\n>>> line.line_dash_dot_setting.space_size\nInt(3)\n```",  # noqa
}



"""Class implementation for the path labels enum.
"""

from enum import Enum


class PathLabel(Enum):
    """
    Enum class for the path labels
    """

    MOVE_TO = "M"
    LINE_TO = "L"
    HORIZONTAL = "H"
    VERTICAL = "V"
    CLOSE = "Z"
    BEZIER_2D = "Q"
    BEZIER_2D_CONTINUAL = "T"
    BEZIER_3D = "C"
    BEZIER_3D_CONTINUAL = "S"



"""This module is for the translation mapping data of the
following document:

Document file: string_comparison_operations.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# String class comparison operations": "# String クラスの比較の各オペレーション",
    ##################################################
    "This page explains the `String` class comparison operations, like the `=`\\, `>=`\\.": "このページでは`String`クラスの`=`や`>=`などの比較のオペレーションについて説明します。",  # noqa
    ##################################################
    "## Comparison return value type": "## 比較のオペレーションの返却値の型",
    ##################################################
    "Each `String` class comparison operation returns a `Boolean` value, not a Python built-in `bool` value.": "`String`クラスの比較の各オペレーションはPyhtonビルトインの`bool`の値ではなく`Boolean`型の値となります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == "Hello"\nassert result\nassert isinstance(result, ap.Boolean)\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == "Hello"\nassert result\nassert isinstance(result, ap.Boolean)\n```',  # noqa
    ##################################################
    "## Acceptable comparison right-side value types": "## 受け付けられる右側の値の型",
    ##################################################
    "The `str` or `String` types of comparison other value (comparison right-side value) types are acceptable, for instance:": "以下のコード例のように`str`もしくは`String`型の比較対象の値（比較の右側の値）を受け付けることができます:",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == "Hello"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == "Hello"\nassert result\n```',  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nstring_2: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == string_2\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nstring_2: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == string_2\nassert result\n```',  # noqa
    ##################################################
    "## Equal comparison": "## 等値条件の比較",
    ##################################################
    "You can use the `==` operator for the equal comparison:": "`==`のオペレーターを使って等値条件の比較を行うことができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == "Hello"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 == "Hello"\nassert result\n```',  # noqa
    ##################################################
    "## Not equal comparison": "## 非等値条件の比較",
    ##################################################
    "You can use the `!=` operator for the not equal comparison:": "`!=`のオペレーターを使って非等値条件の比較を行うことができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 != "World"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("Hello")\nresult: ap.Boolean = string_1 != "World"\nassert result\n```',  # noqa
    ##################################################
    "## Less than or greater than comparison": "## 未満もしくは超過条件の比較",
    ##################################################
    "You can use each less than, less than or equal, greater than, greater than equal comparison, with the `<`\\, `<=`\\, `>`\\, `>=` operators, like the Python built-in `str` value. Sometimes these operations are helpful to compare with the date (or date-time) string.": "未満、以下、超過、以上の比較の処理をPythonビルトインの`str`の値のように`<`、`<=`、`>`、`>=`のオペレーターを使っておこなをことができます。ごの処理は日付や日時などの文字列比較などで役に立つことがあります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 < "1970-01-06"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 < "1970-01-06"\nassert result\n```',  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 <= "1970-01-05"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 <= "1970-01-05"\nassert result\n```',  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 > "1970-01-04"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 > "1970-01-04"\nassert result\n```',  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 >= "1970-01-05"\nassert result\n```': '```py\n# runnable\nimport apysc as ap\n\nstring_1: ap.String = ap.String("1970-01-05")\nresult: ap.Boolean = string_1 >= "1970-01-05"\nassert result\n```',  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: quick_start.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Quick start guide": "# クイックスタートガイド",
    ##################################################
    "This page explains the first step of the apysc library journey.": "このページではapyscのライブラリの最初の一歩としての諸々について説明します。",  # noqa
    ##################################################
    "## Installing": "## インストール",
    ##################################################
    "To use apysc library Python 3.7 or the later version is required.": "apyscのライブラリを使うにはPython3.7もしくはそれ以降のPythonバージョンが必要です。",  # noqa
    ##################################################
    "You can use the pip command to install apysc.": "apyscはpipのコマンドを使ってインストールすることができます。",  # noqa
    ##################################################
    "```\n$ pip install apysc\n```": "```\n$ pip install apysc\n```",
    ##################################################
    "## Create stage and export HTML": "## Stageのインスタンスを作成し、HTMLを出力する",
    ##################################################
    "`Stage` instance is apysc's space for displaying each graphic. You can set arguments of `stage_width` for width setting, `stage_height` for height setting, and `background_color` for background.": "`Stage`のインスタンスはapyscの各グラフィックスを表示する領域となるインスタンスです。幅の設定としての`stage_width`引数、高さの設定としての`stage_height`引数、そして背景色としての`background_color`引数を設定することができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage = ap.Stage(stage_width=300, stage_height=180, background_color="#333")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage = ap.Stage(stage_width=300, stage_height=180, background_color="#333")\n```',  # noqa
    ##################################################
    "Then you can export each HTML and js file by the `save_overall_html` function (in this case, that code displays only the black background stage).": "さらに、結果のHTMLとJavaScriptのファイルを`save_overall_html`関数によって保存することができます（このケースではまだ黒い背景のステージが表示されるだけです）。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=300, stage_height=180, background_color="#333", stage_elem_id="stage"\n)\nap.save_overall_html(dest_dir_path="quick_start_stage_creation/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=300, stage_height=180, background_color="#333", stage_elem_id="stage"\n)\nap.save_overall_html(dest_dir_path="quick_start_stage_creation/")\n```',  # noqa
    ##################################################
    "This code will create each HTML and js files to `dest_dir_path`. You can confirm an exported result by opening `index.html` (`quick_start_stage_creation/index.html`), as follows:": "このコードでは`dest_dir_path`引数に指定されたディレクトリに結果のHTMLとJavaScriptの各ファイルを生成します。以下のコード例では`index.html`のファイル（`quick_start_stage_creation/index.html`）を開くことで出力結果を確認することができます。",  # noqa
    ##################################################
    "## Add sprite container and vector graphics": "## Spriteのコンテナとベクターグラフィックスを追加する",
    ##################################################
    "The `Sprite` class is the container object of each display object, and it can make vector graphics with the `graphics` property.": "`Sprite`クラスは各表示オブジェクトのコンテナとなるクラスであり、`graphics`属性を使ってベクターグラフィックスを生成することもできます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=250, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw polyline vector graphics.\nsprite.graphics.line_style(color="#fff", thickness=3)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=100, y=50)\nsprite.graphics.line_to(x=50, y=100)\nsprite.graphics.line_to(x=100, y=100)\n\n# Draw rectangle vector graphic.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="quick_start_sprite_graphics/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=250, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw polyline vector graphics.\nsprite.graphics.line_style(color="#fff", thickness=3)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=100, y=50)\nsprite.graphics.line_to(x=50, y=100)\nsprite.graphics.line_to(x=100, y=100)\n\n# Draw rectangle vector graphic.\nsprite.graphics.begin_fill(color="#0af")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="quick_start_sprite_graphics/")\n```',  # noqa
    ##################################################
    "Please see each interface documentation page for more details of `Sprite` and `Graphics`\\.": "`Sprite`や`Graphics`クラスの詳細については各インターフェイスのドキュメントをご確認ください。",  # noqa
    ##################################################
    "## See also": "## 関連資料",
    ##################################################
    "- [Sprite class](sprite.md)": "- [Sprite クラス](jp_sprite.md)",
    ##################################################
    "- [Draw interfaces abstract](draw_interfaces_abstract.md)": "- [描画の各インターフェイスの概要](jp_draw_interfaces_abstract.md)",  # noqa
}



"""This module is for the `DisplayObject` subclass implementation
to avoid an abstract method error.
"""

from apysc._display.display_object import DisplayObject
from apysc._display.x_mixin import XMixIn
from apysc._display.y_mixin import YMixIn


class AnyDisplayObject(DisplayObject, XMixIn, YMixIn):
    """This class is for the `DisplayObject` subclass
    implementation to avoid an abstract method error.
    """

    ...



"""Parent-related validation interfaces.
"""

from typing import Any
from typing import Optional


def validate_parent_contains_child(*, parent: Optional[Any], child: Any) -> None:
    """
    Validate whether a parent contains a specified child.

    Parameters
    ----------
    parent : ChildMixIn or None
        Parent instance.
    child : DisplayObject
        Child instance.

    Raises
    ------
    ValueError
        If a parent does not contain a specified child.
        If a parent is None, this interface skips the checking.
    """
    from apysc._display.child_mixin import ChildMixIn
    from apysc._display.display_object import DisplayObject

    parent_: Optional[ChildMixIn] = parent
    child_: DisplayObject = child
    if parent_ is None:
        return
    if parent_.contains(child=child_):
        return
    raise ValueError(
        "Parent not containts specified child."
        f"\nParent type: {type(parent_)}"
        f"\nChild type: {type(child_)}"
        f"\nChild name: {child_.variable_name}"
    )



"""This module is for the translation mapping data of the
following document:

Document file: graphics_base_fill_alpha.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# GraphicsBase fill_alpha interface": "# GraphicsBase クラスの fill_alpha インターフェイス",
    ##################################################
    "This page explains the `GraphicsBase` class `fill_alpha` property interface.": "このページでは`GraphicsBase`クラスの`fill_alpha`属性のインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `fill_alpha` property interface updates or get the instance's fill alpha (opacity).": "`fill_alpha`属性のインターフェイスではインスタンスの塗りの透明度更新や取得を行うことができます。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The getter or setter interface value becomes (or require) the `Number` value (0.0 to 1.0).": "属性のgetterとsetterのインターフェイスの値は`Number`型の値となります（0.0～1.0）。",  # noqa
    ##################################################
    "The following example sets the 0.5 fill alpha to the second rectangle and 0.25 to the third rectangle:": "以下のコード例では2つ目の四角に0.5の透明度を、そして3つ目の四角に0.25の透明度を設定しています:",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=350, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\nrectangle_2.fill_alpha = ap.Number(0.5)\n\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=250, y=50, width=50, height=50)\nrectangle_3.fill_alpha = ap.Number(0.25)\n\nap.save_overall_html(dest_dir_path="./graphics_base_fill_alpha_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=350, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nrectangle_1: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nrectangle_2: ap.Rectangle = sprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\nrectangle_2.fill_alpha = ap.Number(0.5)\n\nrectangle_3: ap.Rectangle = sprite.graphics.draw_rect(x=250, y=50, width=50, height=50)\nrectangle_3.fill_alpha = ap.Number(0.25)\n\nap.save_overall_html(dest_dir_path="./graphics_base_fill_alpha_basic_usage/")\n```',  # noqa
    ##################################################
    "## fill_alpha property API": "## fill_alpha 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get this instance's fill opacity.<hr>": "このインスタンスの塗りの透明度を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `fill_alpha`: Number": "- `fill_alpha`: Number",
    ##################################################
    "  - Current fill opacity (0.0 to 1.0).": "  - 現在の塗りの透明度（0.0～1.0）。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_alpha = ap.Number(0.5)\n>>> rectangle.fill_alpha\nNumber(0.5)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.fill_alpha = ap.Number(0.5)\n>>> rectangle.fill_alpha\nNumber(0.5)\n```',  # noqa
}



"""This module is for the definitions of the custom
event types.
"""

from enum import Enum


class CustomEventType(Enum):

    TIMER_COMPLETE = "timer_complete"
    ANIMATION_COMPLETE = "animation_complete"



"""This module is for the translation mapping data of the
following document:

Document file: graphics_line_style.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Graphics line_style interface": "# Graphics クラスの line_style インターフェイス",
    ##################################################
    "This page explains the `Graphics` class `line_style` method interface.": "このページでは`Graphics`クラスの`line_style`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `line_style` interface sets each line style, such as the line color, line alpha, line thickness, line dot setting. This interface maintains these settings until it is called again or called the `clear` method (similar to the `begin_fill` interface).": "`line_style`インターフェイスは線の色や線の透明度、線幅、点線などの線の各スタイルの設定を行います。このインターフェイスは再度インターフェイスを実行したり`clear`メソッドなどを呼ぶまでスタイル設定を保持し続けます（`begin_fill`インターフェイスと同じような挙動をします）。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "Draw vector graphics interfaces (e.g., the `draw_rect` or `line_to`) use these line settings when creating. Therefore, calling the `line_style` method is necessary before calling each drawing interface.": "`draw_rect`や`line_to`などのベクターグラフィックスの描画系の各インターフェイスはこのインターフェイスのスタイル設定を各グラフィックスインスタンス作成時に参照します。従って線の設定が必要な場合には各描画系のインターフェイスを呼ぶ前にこのインターフェイスで設定を行っておく必要があります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=162, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw a white line with 3px line thickness.\nsprite.graphics.line_style(color="#ccc", thickness=8)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=150, y=50)\n\n# Line style setting will be maintained.\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=150, y=80)\n\n# Change line color and thickness.\nsprite.graphics.line_style(color="#0af", thickness=3)\nsprite.graphics.move_to(x=50, y=110)\nsprite.graphics.line_to(x=150, y=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_basics/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=162, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw a white line with 3px line thickness.\nsprite.graphics.line_style(color="#ccc", thickness=8)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=150, y=50)\n\n# Line style setting will be maintained.\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=150, y=80)\n\n# Change line color and thickness.\nsprite.graphics.line_style(color="#0af", thickness=3)\nsprite.graphics.move_to(x=50, y=110)\nsprite.graphics.line_to(x=150, y=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_basics/")\n```',  # noqa
    ##################################################
    "## Line-color setting": "## 線の色の設定",
    ##################################################
    "The required `color` argument sets the line color.": "指定が必須な`color`引数は線の色を設定します。",
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=102, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set a cyan line color and draw the line.\nsprite.graphics.line_style(color="#0af", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_color/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=102, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set a cyan line color and draw the line.\nsprite.graphics.line_style(color="#0af", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_color/")\n```',  # noqa
    ##################################################
    "If you want to clear line color, specify a blank string to this argument.": "もしも線の色設定を削除したい場合にはこの引数に空文字を指定してください。",  # noqa
    ##################################################
    "For example, the result line graphic becomes invisible since the following code clears the line color setting.": "例えば以下のコード例では線の色設定を削除しているので線は見えなくなっています。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=102, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set a cyan line color.\nsprite.graphics.line_style(color="#0af", thickness=4)\n\n# Clear the line color by specifying a blank string.\nsprite.graphics.line_style(color="", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_clear_line_color/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=102, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set a cyan line color.\nsprite.graphics.line_style(color="#0af", thickness=4)\n\n# Clear the line color by specifying a blank string.\nsprite.graphics.line_style(color="", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_clear_line_color/")\n```',  # noqa
    ##################################################
    "Color code is acceptable like the following list (same as `begin_fill` interface `color` argument):": "以下のリストようなのカラーコードの文字列を指定することができます（`begin_fill`インターフェイスの`color`引数と同じ挙動になります）。",  # noqa
    ##################################################
    "- Six characters, e.g., `#00aaff`.": "- `#00aaff`などの6文字による指定。",
    ##################################################
    "- Three characters, e.g., `#0af` (this becomes `#00aaff`).": "- `#0af`などの3文字による指定（これは`#00aaff`と同じ値として扱われます）。",  # noqa
    ##################################################
    "- Single character, e.g., `#5` (this becomes `#000005`).": "- `#5`などの1文字による指定（これは`000005`と同じ値として扱われます）。",  # noqa
    ##################################################
    "- Skipped `#` symbol, e.g., `0af` (this becomes `#00aaff`).": "- `0af`などの`#`記号を省略した指定（これは`#00aaff`と同じ値として扱われます）。",  # noqa
    ##################################################
    "- Blank string, e.g., `''` (this clears line color setting).": "- `''`などの空文字の指定（これは線の色の削除指定として扱われます）。`",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=162, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# The six characters line color setting (a cyan color).\nsprite.graphics.line_style(color="#00aaff", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\n# The three characters line color setting (a magenta color).\nsprite.graphics.line_style(color="#f0a", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=80, y_end=80)\n\n# The one character line color setting (a black color).\nsprite.graphics.line_style(color="#5", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=110, y_end=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_color_color_code/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=162, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# The six characters line color setting (a cyan color).\nsprite.graphics.line_style(color="#00aaff", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\n# The three characters line color setting (a magenta color).\nsprite.graphics.line_style(color="#f0a", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=80, y_end=80)\n\n# The one character line color setting (a black color).\nsprite.graphics.line_style(color="#5", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=110, y_end=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_color_color_code/")\n```',  # noqa
    ##################################################
    "## Line thickness setting": "## 線幅の設定",
    ##################################################
    "The `thickness` argument sets the line thickness. It can accept greater than or equal to 1.": "`thickness`引数は線の幅を設定します。1以上の値を受け付けることができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=165, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 1-pixel line thickness.\nsprite.graphics.line_style(color="#0af", thickness=1)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\n# Set 4-pixel line thickness.\nsprite.graphics.line_style(color="#0af", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=80, y_end=80)\n\n# Set 10-pixel line thickness.\nsprite.graphics.line_style(color="#0af", thickness=10)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=110, y_end=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_thickness/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=165, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 1-pixel line thickness.\nsprite.graphics.line_style(color="#0af", thickness=1)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\n# Set 4-pixel line thickness.\nsprite.graphics.line_style(color="#0af", thickness=4)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=80, y_end=80)\n\n# Set 10-pixel line thickness.\nsprite.graphics.line_style(color="#0af", thickness=10)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=110, y_end=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_thickness/")\n```',  # noqa
    ##################################################
    "## Line alpha (opacity) setting": "## 線の透明度の設定",
    ##################################################
    "A line alpha (opacity) can be set by the `alpha` argument. It can accept 0.0 (transparent) to 1.0 (opaque).": "`alpha`引数で線の透明度を設定することができます。0.0（透明）～1.0（不透明）の範囲の値を受け付けることができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=150, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw the cyan line from upper-left to lower-right.\nsprite.graphics.line_style(color="#0af", thickness=15, alpha=0.3)\nsprite.graphics.draw_line(x_start=50, x_end=100, y_start=50, y_end=100)\n\n# Draw the magenta line from upper-right to lower-left.\nsprite.graphics.line_style(color="#f0a", thickness=15, alpha=0.3)\nsprite.graphics.draw_line(x_start=100, x_end=50, y_start=50, y_end=100)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_alpha/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=150, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Draw the cyan line from upper-left to lower-right.\nsprite.graphics.line_style(color="#0af", thickness=15, alpha=0.3)\nsprite.graphics.draw_line(x_start=50, x_end=100, y_start=50, y_end=100)\n\n# Draw the magenta line from upper-right to lower-left.\nsprite.graphics.line_style(color="#f0a", thickness=15, alpha=0.3)\nsprite.graphics.draw_line(x_start=100, x_end=50, y_start=50, y_end=100)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_alpha/")\n```',  # noqa
    ##################################################
    "## Line cap setting": "## 線端の設定",
    ##################################################
    "Line cap setting changes line edge style. The `cap` argument sets this style setting, and `LineCaps` enum values are acceptable.": "線の端のスタイルは`cap`引数で設定することができます。`LineCaps`クラスのenumの値を受け付けます。",  # noqa
    ##################################################
    "There are three `LineCaps` options, as follows:": "以下のように`LineCaps`のオプションは3種類存在します:",  # noqa
    ##################################################
    "- BUTT: This is the default value, and it sets no cap.": "- BUTT: デフォルト値であり、端にはなにも設定されません。",  # noqa
    ##################################################
    "- ROUND: This changes the line edge to the rounded one.": "- ROUND: 線の端のスタイルを丸くします。",  # noqa
    ##################################################
    "- SQUARE: This is similar to BUTT, but it increases the line length by the squared edge.": "- SQUARE: 線の端のスタイルを四角くします。これはBUTTと似た表示になりますが、設定される四角の分だけ線が長くなります。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=180, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# BUTT caps setting (default).\nsprite.graphics.line_style(color="#0af", thickness=20, cap=ap.LineCaps.BUTT)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\n# ROUND caps setting.\nsprite.graphics.line_style(color="#0af", thickness=20, cap=ap.LineCaps.ROUND)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=90, y_end=90)\n\n# SQUARE caps setting (same line length setting as BUTT line,\n# but this will be longer for the caps).\nsprite.graphics.line_style(color="#0af", thickness=20, cap=ap.LineCaps.SQUARE)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=130, y_end=130)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_caps/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=200, stage_height=180, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# BUTT caps setting (default).\nsprite.graphics.line_style(color="#0af", thickness=20, cap=ap.LineCaps.BUTT)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=50, y_end=50)\n\n# ROUND caps setting.\nsprite.graphics.line_style(color="#0af", thickness=20, cap=ap.LineCaps.ROUND)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=90, y_end=90)\n\n# SQUARE caps setting (same line length setting as BUTT line,\n# but this will be longer for the caps).\nsprite.graphics.line_style(color="#0af", thickness=20, cap=ap.LineCaps.SQUARE)\nsprite.graphics.draw_line(x_start=50, x_end=150, y_start=130, y_end=130)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_caps/")\n```',  # noqa
    ##################################################
    "## Line joints setting": "## 線の繋ぎ目の設定",
    ##################################################
    "Line joints setting changes the line vertices style. The `joints` argument sets this style, and `LineJoints` enum values are acceptable. The `Polyline` class (`move_to` and `line_to` interfaces) mainly uses this argument.": "`joints`引数では線の繋ぎ目（頂点部分）のスタイルを変更します。この引数には`LineJoints`のenumの各値を受け付けます。主に`move_to`や`line_to`などのインターフェイスで生成される`Polyline`クラスのインスタンスでこの引数は使用されます。",  # noqa
    ##################################################
    "There are three LineJoints enum values, as follows:": "以下のようにLineJointsのenumには3つの値が存在します:",  # noqa
    ##################################################
    "- MITER: This setting sets the style like a picture frame vertices. This setting is the default style setting.": "- MITER: この設定は頂点が（尖った形での）額縁のような形のスタイルが設定されます。この設定がデフォルトのスタイルとなります。",  # noqa
    ##################################################
    "- ROUND: This setting sets the rounded vertices style.": "- ROUND: この設定は丸い頂点のスタイルを設定します。",  # noqa
    ##################################################
    "- BEVEL: This setting sets a beveled vertices style.": "- BEVEL: この設定は射角（ベベル）の頂点のスタイルを設定します。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=350, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set MITER joints setting and draw the polyline.\nsprite.graphics.line_style(color="#0af", thickness=10, joints=ap.LineJoints.MITER)\nsprite.graphics.move_to(x=50, y=100)\nsprite.graphics.line_to(x=75, y=50)\nsprite.graphics.line_to(x=100, y=100)\n\n# Set ROUND joints setting and draw the polyline.\nsprite.graphics.line_style(color="#0af", thickness=10, joints=ap.LineJoints.ROUND)\nsprite.graphics.move_to(x=150, y=100)\nsprite.graphics.line_to(x=175, y=50)\nsprite.graphics.line_to(x=200, y=100)\n\n# Set BEVEL joints setting and draw the polyline.\nsprite.graphics.line_style(color="#0af", thickness=10, joints=ap.LineJoints.BEVEL)\nsprite.graphics.move_to(x=250, y=100)\nsprite.graphics.line_to(x=275, y=50)\nsprite.graphics.line_to(x=300, y=100)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_joints/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=350, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set MITER joints setting and draw the polyline.\nsprite.graphics.line_style(color="#0af", thickness=10, joints=ap.LineJoints.MITER)\nsprite.graphics.move_to(x=50, y=100)\nsprite.graphics.line_to(x=75, y=50)\nsprite.graphics.line_to(x=100, y=100)\n\n# Set ROUND joints setting and draw the polyline.\nsprite.graphics.line_style(color="#0af", thickness=10, joints=ap.LineJoints.ROUND)\nsprite.graphics.move_to(x=150, y=100)\nsprite.graphics.line_to(x=175, y=50)\nsprite.graphics.line_to(x=200, y=100)\n\n# Set BEVEL joints setting and draw the polyline.\nsprite.graphics.line_style(color="#0af", thickness=10, joints=ap.LineJoints.BEVEL)\nsprite.graphics.move_to(x=250, y=100)\nsprite.graphics.line_to(x=275, y=50)\nsprite.graphics.line_to(x=300, y=100)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_joints/")\n```',  # noqa
    ##################################################
    "## Line dot setting": "## 線の点線設定",
    ##################################################
    "Line dot setting changes the line to dotted line. The `dot_setting` argument (`LineDotSetting` value) sets this setting. It can change dot size by the `dot_size` argument (greater than or equal to 1 value is acceptable).": "`dot_setting`引数は線を点線へと変更する設定です。この引数は`LineDotSetting`クラスの設定を受け付けます。点線のサイズは`dot_size`引数で変更することができます（1以上の値を受け付けます）。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=160, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set the line dot settings with 2-pixel dot size and draw the dotted line.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=2)\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set the line dot settings with 5-pixel dot size and draw the dotted line.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=5)\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\n# Set the line dot settings with 10-pixel dot size and draw the dotted line.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=10)\n)\nsprite.graphics.move_to(x=50, y=110)\nsprite.graphics.line_to(x=250, y=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dot_setting/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=160, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set the line dot settings with 2-pixel dot size and draw the dotted line.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=2)\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set the line dot settings with 5-pixel dot size and draw the dotted line.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=5)\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\n# Set the line dot settings with 10-pixel dot size and draw the dotted line.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=10)\n)\nsprite.graphics.move_to(x=50, y=110)\nsprite.graphics.line_to(x=250, y=110)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dot_setting/")\n```',  # noqa
    ##################################################
    "This setting (or the other similar settings) also changes the `Rectangle` or other graphics classes.": "この設定や類似の設定は線のグラフィックスだけでなく`Rectangle`など他のグラフィックスクラスの表示も変更します。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=250, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set the line dot setting with 2-pixel dot size and draw the rectangle.\n# Fill color setting is skipped.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=2)\n)\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Draw the rectangle with the dotted line setting and the fill color.\nsprite.graphics.begin_fill(color="#038")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dot_setting_rectangle/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=250, stage_height=150, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set the line dot setting with 2-pixel dot size and draw the rectangle.\n# Fill color setting is skipped.\nsprite.graphics.line_style(\n    color="#0af", thickness=5, dot_setting=ap.LineDotSetting(dot_size=2)\n)\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Draw the rectangle with the dotted line setting and the fill color.\nsprite.graphics.begin_fill(color="#038")\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dot_setting_rectangle/")\n```',  # noqa
    ##################################################
    "Notes: This setting will be ignored by `draw_line`, `draw_dotted_line`, `draw_dashed_line`, `draw_round_dotted_line`, and `draw_dash_dotted_line` interfaces.": "特記事項: この設定は`draw_line`、`draw_dotted_line`、`draw_dashed_line`、`draw_round_dotted_line`、`draw_dash_dotted_line`の各インターフェイスで無視されます。",  # noqa
    ##################################################
    "## Line dash setting": "## 線の破線設定",
    ##################################################
    "Line dash setting changes the line to the dashed line. The `dash_setting` argument (`LineDashSetting` value) sets this setting. It can change dash size and space size by the `dash_size` and `space_size` arguments.": "`dash_setting`引数は線の破線のスタイル設定を変更します。ごの引数は`LineDashSetting`クラスの設定を受け付けます。この設定では破線のサイズを`dash_size`引数で、空白のスペースのサイズを`space_size`引数で変更することができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 10-pixel dash size and 3-pixel space size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_setting=ap.LineDashSetting(dash_size=10, space_size=3),\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set 15-pixel dash size and 5-pixel space size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_setting=ap.LineDashSetting(dash_size=15, space_size=5),\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dash_setting/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 10-pixel dash size and 3-pixel space size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_setting=ap.LineDashSetting(dash_size=10, space_size=3),\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set 15-pixel dash size and 5-pixel space size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_setting=ap.LineDashSetting(dash_size=15, space_size=5),\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dash_setting/")\n```',  # noqa
    ##################################################
    "Notes: This setting will be ignored by `draw_line`, `draw_dotted_line`, `draw_dashed_line`, `draw_round_dotted_line`, and `draw_dash_dotted_line` interfaces.": "特記事項: この設定は`draw_line`、`draw_dotted_line`、`draw_dashed_line`、`draw_round_dotted_line`、`draw_dash_dotted_line`の各インターフェイスで無視されます。",  # noqa
    ##################################################
    "## Line round dot setting": "## 線の丸ドット設定",
    ##################################################
    "Line round dot setting changes the line to the round dotted line. The `round_dot_setting` argument (`LineRoundDotSetting` value) sets this setting. It can change round size and space size by the `round_size` and `space_size` arguments.": "`round_dot_setting`引数は線の丸ドットのスタイルを設定します。この引数は`LineRoundDotSetting`クラスの値を受け付けます。この設定では円のサイズを`round_size`、円の間のスペースのサイズを`space_size`引数で変更することができます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 5-pixel round size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=5,\n    round_dot_setting=ap.LineRoundDotSetting(round_size=5, space_size=5),\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set 10-pixel round size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=5,\n    round_dot_setting=ap.LineRoundDotSetting(round_size=10, space_size=5),\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_round_dot_setting/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 5-pixel round size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=5,\n    round_dot_setting=ap.LineRoundDotSetting(round_size=5, space_size=5),\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set 10-pixel round size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=5,\n    round_dot_setting=ap.LineRoundDotSetting(round_size=10, space_size=5),\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_round_dot_setting/")\n```',  # noqa
    ##################################################
    "Notes: Since this setting uses the `cap` setting internally, this setting ignores the `cap` setting, increasing the line length by the capsize.": "特記事項: この設定は内部で`cap`設定の値を使用しているため、この設定では`cap`引数の設定が無視されます。また、丸のサイズに応じた分だけ線の長さが長くなります。",  # noqa
    ##################################################
    "Notes: This setting will be ignored by `draw_line`, `draw_dotted_line`, `draw_dashed_line`, `draw_round_dotted_line`, and `draw_dash_dotted_line` interfaces.": "特記事項: この設定は`draw_line`、`draw_dotted_line`、`draw_dashed_line`、`draw_round_dotted_line`、`draw_dash_dotted_line`の各インターフェイスで無視されます。",  # noqa
    ##################################################
    "## Line dash-dot setting": "## 線の一点鎖線の設定",
    ##################################################
    "Line dash-dot setting changes the line to the dash-dotted line (also called long dashed short dashed line or one-dot chain line). The `dash_dot_setting` arguments set this setting and it accepts a `LineDashDotSetting` instance. This argument accepts the `dot_size` (short dashed size), `dash_size` (long dashed size), and `space_size` arguments.": "`dash_dot_setting`引数は線に一点鎖線のスタイルを設定します。この引数は`LineDashDotSetting`クラスのインスタンスを受け付けます。この設定は短い点線のサイズを`dot_size`、長い破線のサイズを`dash_size`、そして空白のスペースのサイズを`space_size`引数で設定できます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 3-pixel dot size and 10-pixel dash size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_dot_setting=ap.LineDashDotSetting(dot_size=3, dash_size=10, space_size=3),\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set 5-pixel dot size and 15-pixel dash size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_dot_setting=ap.LineDashDotSetting(dot_size=5, dash_size=15, space_size=3),\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dash_dot_setting/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    background_color="#333", stage_width=300, stage_height=130, stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\n\n# Set 3-pixel dot size and 10-pixel dash size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_dot_setting=ap.LineDashDotSetting(dot_size=3, dash_size=10, space_size=3),\n)\nsprite.graphics.move_to(x=50, y=50)\nsprite.graphics.line_to(x=250, y=50)\n\n# Set 5-pixel dot size and 15-pixel dash size and draw the line.\nsprite.graphics.line_style(\n    color="#0af",\n    thickness=3,\n    dash_dot_setting=ap.LineDashDotSetting(dot_size=5, dash_size=15, space_size=3),\n)\nsprite.graphics.move_to(x=50, y=80)\nsprite.graphics.line_to(x=250, y=80)\n\nap.save_overall_html(dest_dir_path="graphics_line_style_line_dash_dot_setting/")\n```',  # noqa
    ##################################################
    "Notes: This setting will be ignored by `draw_line`, `draw_dotted_line`, `draw_dashed_line`, `draw_round_dotted_line`, and `draw_dash_dotted_line` interfaces.": "特記事項: この設定は`draw_line`、`draw_dotted_line`、`draw_dashed_line`、`draw_round_dotted_line`、`draw_dash_dotted_line`の各インターフェイスで無視されます。",  # noqa
    ##################################################
    "## line_style API": "## line_style API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Set line style values.<hr>": "線のスタイルを設定します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `color`: String or str": "- `color`: String or str",
    ##################################################
    "  - Hexadecimal color string. e.g., '#00aaff'": "  - '#00aaff'などの16進数の色の文字列。",
    ##################################################
    "- `thickness`: Int or int, default 1": "- `thickness`: Int or int, default 1",
    ##################################################
    "  - Line thickness (minimum value is 1).": "  - 線の幅（1以上の値を受け付けます）。",
    ##################################################
    "- `alpha`: float or Number, default 1.0": "- `alpha`: float or Number, default 1.0",  # noqa
    ##################################################
    "  - Line color opacity (0.0 to 1.0).": "  - 線色の透明度（0.0～1.0）。",
    ##################################################
    "- `cap`: LineCaps or None, default None": "- `cap`: LineCaps or None, default None",  # noqa
    ##################################################
    "  - Line cap (edge style) setting. The not line-related graphics (e.g., Rectangle ignores this, conversely used by Polyline) ignore this setting.": "  - 線の端のスタイル設定。線に関係しないRectangleクラスなどのグラフィックスインスタンスはこの設定を無視します。逆にPolylineクラスなどの線に関係したインスタンスではこの設定を使用します。",  # noqa
    ##################################################
    "- `joints`: LineJoints or None, default None": "- `joints`: LineJoints or None, default None",  # noqa
    ##################################################
    "  - Line vertices (joints) style setting. The not polyline-related graphics (e.g., Rectangle ignores this, conversely used by Polyline) ignore this setting.": "  - 線の頂点（接合部）のスタイル設定。折れ線線に関係しないRectangleなどのグラフィックスインスタンスはこの設定を無視します。逆にPolylineクラスなどの折れ線関係のクラスではこの設定を使用します。",  # noqa
    ##################################################
    "- `dot_setting`: LineDotSetting or None, default None": "- `dot_setting`: LineDotSetting or None, default None",  # noqa
    ##################################################
    "  - Dot setting. If this is specified, it makes a line dotted.": "  - 点線の設定。もしもこの引数が指定された場合、線は点線になります。",  # noqa
    ##################################################
    "- `dash_setting`: LineDashSetting or None, default None": "- `dash_setting`: LineDashSetting or None, default None",  # noqa
    ##################################################
    "  - Dash setting. If this is specified, it makes a line dashed.": "  - 破線の設定。もしこの引数が指定された場合、線は破線になります。",  # noqa
    ##################################################
    "- `round_dot_setting`: LineRoundDotSetting or None, default None": "- `round_dot_setting`: LineRoundDotSetting or None, default None",  # noqa
    ##################################################
    "  - Round dot setting. If this is specified, it makes a line round dotted. Notes: since this style uses a cap setting, it overrides cap and line thickness settings. And it increases the amount of line size. If you want to adjust to the same width of a normal line when using move_to and line_to interfaces, add half-round size to start x-coordinate and subtract from end e-coordinate. e.g., `this.move_to(x + round_size / 2, y)`, `this.line_to(x - round_size / 2, y)`": "  - 丸ドットの設定。もしこの引数が指定された場合、線は丸ドットになります。特記事項: ごの設定は内部でcapの設定を使用しているため、cap（線の端のスタイル設定）と線幅の設定を上書きします。また、cap設定を使用している都合、線の長さも長くなります。move_toやline_toなどのインターフェイスを使った通常の線の長さと合わせたい場合には丸の半分のサイズを線の開始位置のX座標へ加算し、さらに丸の半分のサイズを線の終了位置のX座標から減算してください（Y座標も同様です）。例: `this.move_to(x + round_size / 2, y)`、`this.line_to(x - round_size / 2, y)`",  # noqa
    ##################################################
    "- `dash_dot_setting`: LineDashDotSetting or None, default None": "- `dash_dot_setting`: LineDashDotSetting or None, default None",  # noqa
    ##################################################
    "  - Dash dot (1-dot chain) setting. If this is specified, it makes a line 1-dot chained.": "  - 一点鎖線のスタイル設定。もしこの引数が指定された場合、線の一点鎖線になります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> line: ap.Line = sprite.graphics.draw_line(\n...     x_start=50, y_start=50, x_end=150, y_end=50\n... )\n>>> line.line_color\nString('#ffffff')\n\n>>> line.line_thickness\nInt(5)\n\n>>> line.line_alpha\nNumber(0.5)\n\n>>> line.line_cap\nString('round')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> line: ap.Line = sprite.graphics.draw_line(\n...     x_start=50, y_start=50, x_end=150, y_end=50\n... )\n>>> line.line_color\nString('#ffffff')\n\n>>> line.line_thickness\nInt(5)\n\n>>> line.line_alpha\nNumber(0.5)\n\n>>> line.line_cap\nString('round')\n```",  # noqa
    ##################################################
    "## line_color property API": "## line_color 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line color.<hr>": "現在の線の色を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_color`: String": "- `line_color`: String",
    ##################################################
    "  - Current line color (hexadecimal string, e.g., '#00aaff'). If not be set, this interface returns a blank string.": "  - '#00aaff'などの16進数の線の色。もし設定されていない場合はこの空文字となります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> sprite.graphics.line_color\nString('#ffffff')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> sprite.graphics.line_color\nString('#ffffff')\n```",  # noqa
    ##################################################
    "## line_thickness property API": "## line_thickness 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line thickness.<hr>": "現在の線の線幅を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_thickness`: Int": "- `line_thickness`: Int",
    ##################################################
    "  - Current line thickness.": "  - 現在の線幅。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color="#fff", thickness=5, alpha=0.5)\n>>> sprite.graphics.line_thickness\nInt(5)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(color="#fff", thickness=5, alpha=0.5)\n>>> sprite.graphics.line_thickness\nInt(5)\n```',  # noqa
    ##################################################
    "## line_alpha property API": "## line_alpha 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line color opacity.<hr>": "現在の線の透明度を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_alpha`: Number": "- `line_alpha`: Number",
    ##################################################
    "  - Current line opacity (0.0 to 1.0).": "  - 現在の線の透明度（0.0～1.0）。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> sprite.graphics.line_alpha\nNumber(0.5)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> sprite.graphics.line_alpha\nNumber(0.5)\n```',  # noqa
    ##################################################
    "## line_cap property API": "## line_cap 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line cap (edge) style setting.<hr>": "現在の線の端のスタイル設定。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_cap`: String": "- `line_cap`: String",
    ##################################################
    "  - Current line cap (edge) style setting.": "  - 現在の線の端のスタイル設定。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> sprite.graphics.line_cap\nString('round')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, alpha=0.5, cap=ap.LineCaps.ROUND\n... )\n>>> sprite.graphics.line_cap\nString('round')\n```",  # noqa
    ##################################################
    "## line_joints property API": "## line_joints 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line joints (vertices) style setting.<hr>": "現在の線の接合部（頂点）のスタイル設定を取得します。<hr>",  # noqa
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_joints`: String": "- `line_joints`: String",
    ##################################################
    "  - Current line joints (vertices) style setting.": "  - 現在の線の接合部（頂点）のスタイル設定。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, joints=ap.LineJoints.ROUND\n... )\n>>> sprite.graphics.line_joints\nString('round')\n```": "```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color=\"#fff\", thickness=5, joints=ap.LineJoints.ROUND\n... )\n>>> sprite.graphics.line_joints\nString('round')\n```",  # noqa
    ##################################################
    "## line_dot_setting property API": "## line_dot_setting 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line dot setting.<hr>": "現在の線の点線設定を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_dot_setting`: LineDotSetting or None": "- `line_dot_setting`: LineDotSetting or None",  # noqa
    ##################################################
    "  - Current line dot setting.": "  - 現在の点線設定。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff", thickness=5, dot_setting=ap.LineDotSetting(dot_size=5)\n... )\n>>> sprite.graphics.line_dot_setting.dot_size\nInt(5)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff", thickness=5, dot_setting=ap.LineDotSetting(dot_size=5)\n... )\n>>> sprite.graphics.line_dot_setting.dot_size\nInt(5)\n```',  # noqa
    ##################################################
    "## line_dash_setting property API": "## line_dash_setting 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line dash setting.<hr>": "現在の線の破線のスタイル設定を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_dash_setting`: LineDashSetting or None": "- `line_dash_setting`: LineDashSetting or None",  # noqa
    ##################################################
    "  - Current line dash setting.": "  - 現在の破線設定。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff",\n...     thickness=5,\n...     dash_setting=ap.LineDashSetting(dash_size=10, space_size=5),\n... )\n>>> sprite.graphics.line_dash_setting.dash_size\nInt(10)\n\n>>> sprite.graphics.line_dash_setting.space_size\nInt(5)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff",\n...     thickness=5,\n...     dash_setting=ap.LineDashSetting(dash_size=10, space_size=5),\n... )\n>>> sprite.graphics.line_dash_setting.dash_size\nInt(10)\n\n>>> sprite.graphics.line_dash_setting.space_size\nInt(5)\n```',  # noqa
    ##################################################
    "## line_round_dot_setting property API": "## line_round_dot_setting 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line round dot setting.<hr>": "現在の線の丸ドットのスタイル設定を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_round_dot_setting`: LineRoundDotSetting or None": "- `line_round_dot_setting`: LineRoundDotSetting or None",  # noqa
    ##################################################
    "  - Current line round dot setting.": "  - 現在の線の丸ドットのスタイル設定。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff",\n...     thickness=5,\n...     round_dot_setting=ap.LineRoundDotSetting(round_size=6, space_size=3),\n... )\n>>> sprite.graphics.line_round_dot_setting.round_size\nInt(6)\n\n>>> sprite.graphics.line_round_dot_setting.space_size\nInt(3)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff",\n...     thickness=5,\n...     round_dot_setting=ap.LineRoundDotSetting(round_size=6, space_size=3),\n... )\n>>> sprite.graphics.line_round_dot_setting.round_size\nInt(6)\n\n>>> sprite.graphics.line_round_dot_setting.space_size\nInt(3)\n```',  # noqa
    ##################################################
    "## line_dash_dot_setting property API": "## line_dash_dot_setting 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get current line dash dot setting.<hr>": "現在の線の一点鎖線のスタイル設定を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `line_dash_dot_setting`: LineDashDotSetting or None": "- `line_dash_dot_setting`: LineDashDotSetting or None",  # noqa
    ##################################################
    "  - Current line dash dot setting.": "  - 現在の一点鎖線のスタイル設定。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff",\n...     thickness=5,\n...     dash_dot_setting=ap.LineDashDotSetting(\n...         dot_size=2, dash_size=5, space_size=3\n...     ),\n... )\n>>> sprite.graphics.line_dash_dot_setting.dot_size\nInt(2)\n\n>>> sprite.graphics.line_dash_dot_setting.dash_size\nInt(5)\n\n>>> sprite.graphics.line_dash_dot_setting.space_size\nInt(3)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.line_style(\n...     color="#fff",\n...     thickness=5,\n...     dash_dot_setting=ap.LineDashDotSetting(\n...         dot_size=2, dash_size=5, space_size=3\n...     ),\n... )\n>>> sprite.graphics.line_dash_dot_setting.dot_size\nInt(2)\n\n>>> sprite.graphics.line_dash_dot_setting.dash_size\nInt(5)\n\n>>> sprite.graphics.line_dash_dot_setting.space_size\nInt(3)\n```',  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: graphics_base_skew.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# GraphicsBase skew_x and skew_y interfaces": "# GraphicsBase クラスの skew_x と skew_y インターフェイス",  # noqa
    ##################################################
    "This page explains the `GraphicsBase` class (base class of each graphic, such as the `Rectangle`) `skew_x` and `skew_y` property interfaces.": "このページでは`GraphicsBase`クラス（`Rectangle`などのグラフィッククラスの基底クラス）の`skew_x`と`skew_y`属性のインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interfaces are these?": "## 各インターフェイスの概要",
    ##################################################
    "The `skew_x` property skews an object's x-axis. Conversely, the `skew_y` property skew a y-axis. These interfaces have getter and setter interfaces.": "`skew_x`属性はオブジェクトをX軸方向に歪ませます。逆に`skew_y`属性ではY軸方向にオブジェクトを歪ませます。これらのインターフェイスはgetterとsetterの各インターフェイスを持っています。",  # noqa
    ##################################################
    "Each interface value type is the `Int` value.": "各インターフェイスの値の型は`Int`型の値となります。",
    ##################################################
    "The following example shows you the default rectangle (left) and the skewed 50px in the x-direction rectangle (right).": "以下のコード例では左側の四角はデフォルトの状態、右側の四角はX軸方向に50pxの歪みを設定しています。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=250, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nleft_rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n    x=50, y=50, width=50, height=50\n)\nright_rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n    x=150, y=50, width=50, height=50\n)\nright_rectangle.skew_x = ap.Int(50)\n\nap.save_overall_html(dest_dir_path="graphics_base_skew_x_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=250, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nleft_rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n    x=50, y=50, width=50, height=50\n)\nright_rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n    x=150, y=50, width=50, height=50\n)\nright_rectangle.skew_x = ap.Int(50)\n\nap.save_overall_html(dest_dir_path="graphics_base_skew_x_basic_usage/")\n```',  # noqa
    ##################################################
    "The following example skews the rectangle in the y-direction incrementally.": "以下の例ではY軸方向に四角の歪みを加算していく形で設定しています。",  # noqa
    ##################################################
    '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: _RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.skew_y += 1\n\n\nap.Stage(\n    stage_width=150, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\noptions: _RectOptions = {"rectangle": rectangle}\ntimer: ap.Timer = ap.Timer(handler=on_timer, delay=ap.FPS.FPS_60, options=options)\ntimer.start()\n\nap.save_overall_html(dest_dir_path="graphics_base_skew_y_incremental_basic_usage/")\n```': '```py\n# runnable\nfrom typing_extensions import TypedDict\n\nimport apysc as ap\n\n\nclass _RectOptions(TypedDict):\n    rectangle: ap.Rectangle\n\n\ndef on_timer(e: ap.TimerEvent, options: _RectOptions) -> None:\n    """\n    The handler that the timer calls.\n\n    Parameters\n    ----------\n    e : TimerEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = options["rectangle"]\n    rectangle.skew_y += 1\n\n\nap.Stage(\n    stage_width=150, stage_height=150, background_color="#333", stage_elem_id="stage"\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color="#0af")\n\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\noptions: _RectOptions = {"rectangle": rectangle}\ntimer: ap.Timer = ap.Timer(handler=on_timer, delay=ap.FPS.FPS_60, options=options)\ntimer.start()\n\nap.save_overall_html(dest_dir_path="graphics_base_skew_y_incremental_basic_usage/")\n```',  # noqa
    ##################################################
    "## skew_x property API": "## skew_x property API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a current skew x value of the instance.<hr>": "インスタンスの現在のX軸の歪みの値を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `skew_x`: Int": "- `skew_x`: Int",
    ##################################################
    "  - Current skew x value of this instance.": "  - インスタンスの現在のX軸の歪みの値。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.skew_x = ap.Int(50)\n>>> rectangle.skew_x\nInt(50)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.skew_x = ap.Int(50)\n>>> rectangle.skew_x\nInt(50)\n```',  # noqa
    ##################################################
    "## skew_y property API": "## skew_y property API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a current skew y value of the instance.<hr>": "インスタンスの現在のY軸の歪みの値を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `skew_y`: Int": "- `skew_y`: Int",
    ##################################################
    "  - Current skew y value of the instance.": "  - インスタンスの現在のY軸の歪みの値。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.skew_y = ap.Int(50)\n>>> rectangle.skew_y\nInt(50)\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color="#0af")\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> rectangle.skew_y = ap.Int(50)\n>>> rectangle.skew_y\nInt(50)\n```',  # noqa
}
